binary_wrapper!() { /* proc-macro */ }Expand description
A procedural macro for generating implementations for core binary operations on a wrapper type
binary_wrapper!() { /* proc-macro */ }A procedural macro for generating implementations for core binary operations on a wrapper type